@@ -1,12 +1,22 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2017 The Qt Company Ltd.
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the examples of the Qt Toolkit.
 **
 ** $QT_BEGIN_LICENSE:BSD$
-** You may use this file under the terms of the BSD license as follows:
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
+**
+** BSD License Usage
+** Alternatively, you may use this file under the terms of the BSD license
+** as follows:
 **
 ** "Redistribution and use in source and binary forms, with or without
 ** modification, are permitted provided that the following conditions are
@@ -17,8 +27,8 @@
 **     notice, this list of conditions and the following disclaimer in
 **     the documentation and/or other materials provided with the
 **     distribution.
-**   * Neither the name of Digia Plc and its Subsidiary(-ies) nor the names
-**     of its contributors may be used to endorse or promote products derived
+**   * Neither the name of The Qt Company Ltd nor the names of its
+**     contributors may be used to endorse or promote products derived
 **     from this software without specific prior written permission.
 **
 **
@@ -39,7 +49,8 @@
 ****************************************************************************/
 #include "svgview.h"
 
-#include <QFile>
+#include <QSvgRenderer>
+
 #include <QWheelEvent>
 #include <QMouseEvent>
 #include <QGraphicsRectItem>
@@ -54,9 +65,9 @@
 SvgView::SvgView(QWidget *parent)
     : QGraphicsView(parent)
     , m_renderer(Native)
-    , m_svgItem(0)
-    , m_backgroundItem(0)
-    , m_outlineItem(0)
+    , m_svgItem(nullptr)
+    , m_backgroundItem(nullptr)
+    , m_outlineItem(nullptr)
 {
     setScene(new QGraphicsScene(this));
     setTransformationAnchor(AnchorUnderMouse);
@@ -83,20 +94,26 @@ void SvgView::drawBackground(QPainter *p, const QRectF &)
     p->restore();
 }
 
-void SvgView::openFile(const QFile &file)
+QSize SvgView::svgSize() const
 {
-    if (!file.exists())
-        return;
+    return m_svgItem ? m_svgItem->boundingRect().size().toSize() : QSize();
+}
 
+bool SvgView::openFile(const QString &fileName)
+{
     QGraphicsScene *s = scene();
 
-    bool drawBackground = (m_backgroundItem ? m_backgroundItem->isVisible() : false);
-    bool drawOutline = (m_outlineItem ? m_outlineItem->isVisible() : true);
+    const bool drawBackground = (m_backgroundItem ? m_backgroundItem->isVisible() : false);
+    const bool drawOutline = (m_outlineItem ? m_outlineItem->isVisible() : true);
+
+    QScopedPointer<QGraphicsSvgItem> svgItem(new QGraphicsSvgItem(fileName));
+    if (!svgItem->renderer()->isValid())
+        return false;
 
     s->clear();
     resetTransform();
 
-    m_svgItem = new QGraphicsSvgItem(file.fileName());
+    m_svgItem = svgItem.take();
     m_svgItem->setFlags(QGraphicsItem::ItemClipsToShape);
     m_svgItem->setCacheMode(QGraphicsItem::NoCache);
     m_svgItem->setZValue(0);
@@ -120,6 +137,7 @@ void SvgView::openFile(const QFile &file)
     s->addItem(m_outlineItem);
 
     s->setSceneRect(m_outlineItem->boundingRect().adjusted(-10, -10, 10, 10));
+    return true;
 }
 
 void SvgView::setRenderer(RendererType type)
@@ -186,3 +204,9 @@ void SvgView::wheelEvent(QWheelEvent *event)
     event->accept();
 }
 
+QSvgRenderer *SvgView::renderer() const
+{
+    if (m_svgItem)
+        return m_svgItem->renderer();
+    return nullptr;
+}
